==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer/src/com/sslexplorer/policyframework/DefaultAccessRights.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.policyframework;

import java.util.Calendar;
import java.util.List;

public class DefaultAccessRights extends AbstractResource implements AccessRights {
    
    private List<AccessRight> permissions;
    private List rules;    
    private String permissionClass;
    
    public DefaultAccessRights(int realmID, int resourceID, String resourceName, String resourceDescription, List<AccessRight> permissions, String permissionClass, Calendar dateCreated, Calendar dateAmended) {
        super(realmID, PolicyConstants.ACCESS_RIGHTS_RESOURCE_TYPE, resourceID, resourceName, resourceDescription, dateCreated, dateAmended);
        this.permissions = permissions;
        this.permissionClass = permissionClass;
    }

    public void addAccessRight(AccessRight perm) {
        permissions.add(perm);
    }

    public void removeAccessRight(AccessRight perm) {
        permissions.remove(perm);
    }

    public List<AccessRight> getAccessRights() {
        return permissions;
    }

    public List getRules() {
        return rules;
    }

    public void addRule(Rule rule) {
        rules.add(rule);
    }

    public void removeRule(Rule rule) {
        rules.remove(rule);
    }

    public String getAccessRightsClass() {
        return permissionClass;
    }

    public boolean containsAccessRight(AccessRight accessRight) {
        return permissions.contains(accessRight);
    }
}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer/src/com/sslexplorer/policyframework/DefaultAccessRights.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.policyframework;

import java.util.Calendar;
import java.util.Collections;
import java.util.List;

public class DefaultAccessRights extends AbstractResource implements AccessRights {
    
    private List<AccessRight> permissions;
    private List rules;    
    private String permissionClass;
    
    public DefaultAccessRights(int realmID, int resourceID, String resourceName, String resourceDescription, List<AccessRight> permissions, String permissionClass, Calendar dateCreated, Calendar dateAmended) {
        super(realmID, PolicyConstants.ACCESS_RIGHTS_RESOURCE_TYPE, resourceID, resourceName, resourceDescription, dateCreated, dateAmended);
        this.permissions = permissions == null ? Collections.EMPTY_LIST : permissions;
        this.permissionClass = permissionClass;
    }

    public void addAccessRight(AccessRight perm) {
        permissions.add(perm);
    }

    public void removeAccessRight(AccessRight perm) {
        permissions.remove(perm);
    }

    public List<AccessRight> getAccessRights() {
        return permissions;
    }

    public List getRules() {
        return rules;
    }

    public void addRule(Rule rule) {
        rules.add(rule);
    }

    public void removeRule(Rule rule) {
        rules.remove(rule);
    }

    public String getAccessRightsClass() {
        return permissionClass;
    }

    public boolean containsAccessRight(AccessRight accessRight) {
        return permissions.contains(accessRight);
    }
}
